\NeedsTeXFormat{LaTeX2e}

\ProvidesClass{TU_Thesis_Spatial_Planning}

\def\title#1{\gdef\@title{#1}}
\def\@subtitle{}
\def\subtitle#1{\gdef\@subtitle{#1}}
\def\authordegree#1{\gdef\@authordegree{#1}}
\def\datedefense#1{\gdef\@datedefense{#1}}
\def\birthplace#1{\gdef\@birthplace{#1}}
\def\supervisora#1{\gdef\@supervisora{#1}}
\def\@supervisorb{}
\def\supervisorb#1{\gdef\@supervisorb{#1}}

\newif\if@german
\@germanfalse
\DeclareOption{german}{\@germantrue}

\ProcessOptions\relax

\LoadClass[11pt,a4paper,twoside,openright]{report}

\if@german
    \RequirePackage[ngerman]{babel}
    %\RequirePackage[T1]{fontenc}
\else
    \RequirePackage[english]{babel}
    \RequirePackage[UKenglish]{isodate}
\fi



\RequirePackage[utf8]{inputenc}
\RequirePackage{natbib}
\RequirePackage{soul}
\RequirePackage[pagestyles]{titlesec}
% provides comfortable options for adjusting page margins
\RequirePackage{anysize}
% removes page numbering from parts
\RequirePackage{nonumonpart}
% makes it easier to adjust line spacing
\RequirePackage{setspace}
% removes footers and headers from empty pages
\RequirePackage{emptypage}
\RequirePackage{graphicx}
\RequirePackage[colorlinks=false,linkcolor=black,plainpages=false]{hyperref}
\RequirePackage{siunitx}
\RequirePackage{amsmath}
\RequirePackage{tabularx}
\RequirePackage{multirow}
\RequirePackage{booktabs}
% allows including pdfs into the document
\RequirePackage{pdfpages}
\RequirePackage{tocloft}
\RequirePackage{fancyhdr}
\RequirePackage{acronym}
\RequirePackage{caption}
\RequirePackage{bibentry}
\RequirePackage{float}

\captionsetup[table]{skip=10pt}

\newcommand{\initialise}{
    \clubpenalty10000
    \widowpenalty10000
    \displaywidowpenalty=10000
    \spacing{1.1}
    \newcounter{paper}
}

\newcommand{\makecoverpage}{
    \thispagestyle{empty}
    \fontfamily{ptm}\selectfont
	\begin{titlepage}
	\begin{center}
	\vspace{2cm}
	{
		\sffamily
		\fontsize{20}{20}\selectfont
		\vfill\uppercase{\textbf{\so{Inaugural -- Dissertation}}}\vfill
	}
	\vspace{1cm}
	{
		\fontsize{18}{30}\selectfont
		zur\\
		Erlangung der Doktorwürde\\
		der\\
		Fakultät Raumplanung\\
		der\\
		Technischen Universität\\
		Dortmund\\
	}
	\vfill
	{
		\fontsize{12}{16}\selectfont
		\begin{flushleft}
		Vorgelegt von\\
		\@authordegree\\
		aus: \@birthplace \\
		\vspace{0.25cm}
		Tag der mündlichen Prüfung: \@datedefense
		\end{flushleft}
	}
	\end{center}
	\end{titlepage}
	\cleardoublepage
}

\newcommand{\maketitlepage}{
    \thispagestyle{empty}
    \begin{center}
    {
    	\fontsize{20}{20}\selectfont
    	\if@german
    	    Thema\\
    	\else
    	    Topic\\
    	\fi
    }
    \vspace{3cm}
    {
    	{\fontsize{24}{30}\selectfont
    	\textsl{\@title}\par}
    	\vspace{1cm}
    	\ifx\@subtitle\empty{}
    	\else
    	    {\fontsize{24}{30}\selectfont ---}\par
    	    \vspace{1cm}
    	    {\fontsize{18}{30}\selectfont
    		    \textsl{\@subtitle}}
    	\fi 
    }
    \vfill
    \begin{flushleft}
    {
    	\fontsize{14}{13}\selectfont\singlespacing
    	\if@german
    	    Betreuer:\\
    	\else{
    	    \ifx\@supervisorb\empty{}
    	        Supervisor:\\
    	    \else
    	        Supervisors:\\
    	    \fi
    	}
    	\fi
    	\vspace{0.25cm}
    	\@supervisora\\
    	\ifx\@supervisorb\empty{}
    	\else
    	    \@supervisorb
    	\fi
    }
    \end{flushleft}
    \end{center}
    \cleardoublepage
    \fontfamily{ptm}\selectfont
    \pagestyle{plain}
}

\newcommand{\makeaffidavit}{
    \chapter*{Eidesstattliche Versicherung}
    \addcontentsline{toc}{chapter}{Eidesstattliche Versicherung}
    %\thispagestyle{empty}
    Gemäß § 11 der Promotionsordnung der Fakultät Raumplanung der Technischen Universität Dortmund erkläre ich folgende Punkte:
    \begin{enumerate}
    	\item Bei der eingereichten Dissertation zu dem Thema \glqq \textit{\@title}\grqq\ handelt es sich um meine eigenständig erbrachte Leistung.
    	\item Ich habe nur die angegebenen Quellen und Hilfsmittel benutzt und mich keiner unzulässigen Hilfe Dritter bedient. Insbesondere habe ich wörtlich oder sinngemäß aus anderen Werken übernommene Inhalte als solche kenntlich gemacht.
    	\item Die Arbeit oder Teile davon habe ich bislang nicht an einer Hochschule des In- oder Auslands als Bestandteil einer Prüfungs- oder Qualifikationsleistung vorgelegt.
    	\item Die Richtigkeit der vorstehenden Erklärungen bestätige ich.
    	\item Die Bedeutung der eidesstattlichen Versicherung und die strafrechtlichen Folgen einer unrichtigen oder unvollständigen eidesstattlichen Versicherung sind mir bekannt.
    \end{enumerate}
    
    \noindent Ich versichere an Eides statt, dass ich nach bestem Wissen die reine Wahrheit erklärt und nichts verschwiegen habe.
    
    \vspace{2cm}
	\par\noindent\makebox[2.0in]{\hrulefill} \hfill\makebox[3.5in]{\hrulefill}
	\par\noindent\makebox[2.0in][l]{Ort und Datum} \hfill\makebox[3.5in][l]{\ \@author}
	\cleardoublepage
    %\pagestyle{plain}
}

\newcommand{\makeappendix}{
    \cleardoublepage
    \renewcommand{\thesection}{A\arabic{section}}
    \pagenumbering{Roman}
    \if@german
        \chapter*{Anhang}
        \addcontentsline{toc}{chapter}{Anhang}
    \else
        \chapter*{Appendix}
        \addcontentsline{toc}{chapter}{Appendix}
    \fi
    \setcounter{section}{0}
    \setcounter{figure}{0}
    \setcounter{equation}{0}
    \setcounter{table}{0}
}

\newcommand{\listfigures}{
    \if@german
        \phantomsection\addcontentsline{toc}{chapter}{Abbildungsverzeichnis}
    \else
        \phantomsection\addcontentsline{toc}{chapter}{List of Figures}
    \fi
    \listoffigures
    \clearpage
}

\newcommand{\listtables}{
    \if@german
        \phantomsection\addcontentsline{toc}{chapter}{Tabellenverzeichnis}
    \else
        \phantomsection\addcontentsline{toc}{chapter}{List of Tables}
    \fi
    \listoftables
    \clearpage
}

\newcommand{\synopsis}{
    \if@german
        \part{Synopse}
    \else
        \part{Synopsis}
    \fi
}

\newcommand{\publications}{
    \if@german
        \part{Publikationen}
    \else
        \part{Publications}
    \fi
    \setcounter{chapter}{0}
}

\newcommand{\addpaper}[2]{
    %\def\paperlabel{#2}
    \def\paperpath{#1}
    \def\scaling{#2}
    %\includepdf[pages=-,scale=\scaling,offset=\ifodd-\c@page\fi15pt 0,pagecommand={\label{paper\thepaper}}]{\paperpath}
    %\includepdf[pages=-,scale=\scaling,offset=\ifodd-\c@page\fi15pt 0,pagecommand={}]{\paperpath}
    \includepdf[pages=-,scale=\scaling,offset=\ifodd-\c@page\fi15pt 0,pagecommand={}, addtotoc={1, chapter, 0, \papertitle, paper\thepaper}]{\paperpath}
    \cleardoublepage
}

\newcommand{\generatebibliography}[1]{
    \def\bibpath{#1}
    \cleardoublepage
    \if@german
        \addcontentsline{toc}{chapter}{Literaturverzeichnis}
        \bibliographystyle{apalike-german}
        \bibliography{\bibpath}
    \else
        \addcontentsline{toc}{chapter}{Bibliography}
        \bibliographystyle{apalike}
        \bibliography{\bibpath}
    \fi
    \nobibliography*
}

\newenvironment{preamble}
{
    % adjust the page numbering to roman style
    \pagenumbering{roman}
    % dotted lines for chapters within table of contents
    \renewcommand{\cftchapleader}{\cftdotfill{\cftdotsep}}
}
{
    % add a little space between the main parts and the preamble
    \addtocontents{toc}{\protect\vspace*{\baselineskip}}
    % set back the figure counter (just in case figures are used up to here)
    \setcounter{figure}{0}
    % adjust the numbering to alphanumeric style (characters)
    \pagenumbering{arabic}
}

\newenvironment{acknowledgements}
{
    \if@german {
        \chapter*{Danksagung}\label{danksagung}
        \addcontentsline{toc}{chapter}{Danksagung}
    }\else {
        \chapter*{Acknowledgements}\label{acknowledgements}
        \addcontentsline{toc}{chapter}{Acknowledgements}
    }
    \fi
}
{
    \par
    \vspace{1cm}
    \if@german
        \noindent \@author \hfill Dortmund, den \today
    \else
        \noindent \@author \hfill Dortmund, {\cleanlookdateon\today}
    \fi
    \clearpage
}

\newenvironment{englishabstract}
{
    \chapter*{Abstract}\label{abstract}
    \addcontentsline{toc}{chapter}{Abstract}
}
{\clearpage}

\newenvironment{germanabstract}
{
    \chapter*{Kurzzusammenfassung}\label{kurzzusammenfassung}
    \addcontentsline{toc}{chapter}{Kurzzusammenfassung}
}
{\clearpage}

\newenvironment{abbreviations}
{
    \if@german
        \chapter*{Abkürzungsverzeichnis}
        \addcontentsline{toc}{chapter}{Abkürzungsverzeichnis}
    \else
        \section*{List of Abbreviations}
        \addcontentsline{toc}{chapter}{List of Abbreviations}
    \fi
    \begin{acronym}[abbreviations]
    \setlength{\parskip}{-1ex}
}
{
    \end{acronym}
    \cleardoublepage
}

\newcommand{\makepaperreference}[1]{
    \gdef\paperreference{#1}
    \if@german
        \parbox{3cm}{\textbf{Referenz}}
    \else
        \parbox{3cm}{\textbf{Reference}}
    \fi
    & \parbox{11.5cm}{\bibentry{\paperreference}}\\
    \parbox{3cm}{} & \parbox{11.5cm}{} \\
}

\newcommand{\makepapertitle}[1]{
    \gdef\papertitle{#1}
    %\phantomsection\addcontentsline{toc}{chapter}{\thepaper\hspace{.43cm}\papertitle}
}

\newcommand{\makepapercontributions}[1]{
    \gdef\papercontributions{#1}
    \if@german
        \parbox{3cm}{\textbf{Beiträge}}
    \else
        \parbox{3cm}{\textbf{Contributions}}
    \fi
    & \parbox{11.5cm}{\papercontributions}\\
    \parbox{3cm}{} & \parbox{11.5cm}{} \\
}

\newcommand{\makepaperdates}[3]{
    \gdef\papersubmitted{#1}
    \gdef\paperaccepted{#2}
    \gdef\paperpublished{}
    \gdef\paperpublished{#3}
    \if@german
        \parbox{3cm}{\textbf{Historie}} 
    \else
        \parbox{3cm}{\textbf{History}}
    \fi 
    &
    \if@german
        \ifx\paperpublished\empty{}
            \parbox{11.5cm}{Eingereicht: \papersubmitted \\ Akzeptiert: \paperaccepted}\\
        \else
            \parbox{11.5cm}{Eingereicht: \papersubmitted \\ Akzeptiert: \paperaccepted \\ Veröffentlicht: \paperpublished}\\
        \fi
    \else
        \ifx\paperpublished\empty{}
            \parbox{11.5cm}{Submitted: \papersubmitted \\ Accepted: \paperaccepted}\\
        \else
            \parbox{11.5cm}{Submitted: \papersubmitted \\ Accepted: \paperaccepted \\ Published: \paperpublished}\\
        \fi
    \fi
}

\newcommand{\SignatureAndDate}[1]{
    \par\noindent\makebox[3.5in]{\hrulefill} \hfill\makebox[2.0in]{\hrulefill}
    \if@german
        \par\noindent\makebox[3.5in][l]{\ #1}      \hfill\makebox[2.0in][l]{\ Datum}
    \else
        \par\noindent\makebox[3.5in][l]{\ #1}      \hfill\makebox[2.0in][l]{\ Date}
    \fi
    \vspace{1cm}
}

\newenvironment{papersummary}
{
    \thispagestyle{empty}
    \addtocounter{paper}{1}
    \if@german{
        \section*{Artikel \thepaper: Eckdaten und Autorenbeiträge}
    }\else{
        \section*{Article \thepaper: Key facts and author contributions}
    }\fi
    \begin{table}[H]
    \renewcommand*{\arraystretch}{1.5}
    %\setlength{\extrarowheight}{60pt}
    \centering
    \begin{tabular}{m{3cm}|m{11.5cm}}
}
{
    \end{tabular}
    \end{table}
    \vspace{1cm}
    \if@german
        \noindent\textbf{Unterschriften:}
    \else
        \noindent\textbf{Signature:}
    \fi
    \vspace{1.5cm}
}